@@ -1,26 +1,12 @@
 /*
-  Copyright (c) 2019-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "emoticonunicodetab.h"
 #include "emoticonlistwidgetselector.h"
 #include "textutils.h"
-#include "emoticonunicodeutils.h"
 #include <KLocalizedString>
 
 using namespace KPIMTextEdit;
@@ -79,7 +65,7 @@ void EmoticonUnicodeTab::loadEmoticons()
 void EmoticonUnicodeTab::createPlainTextEmoticonTab(const QString &str, const QVector<EmoticonUnicodeUtils::EmoticonStruct> &emoticons)
 {
     if (!emoticons.isEmpty()) {
-        EmoticonListWidgetSelector *selector = new EmoticonListWidgetSelector(this);
+        auto *selector = new EmoticonListWidgetSelector(this);
         connect(selector, &KPIMTextEdit::EmoticonListWidgetSelector::itemSelected, this, &EmoticonUnicodeTab::itemSelected);
         QStringList lst;
         lst.reserve(emoticons.count());
