@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "textgotolinewidgettest.h"
@@ -37,12 +24,12 @@ void TextGoToLineWidgetTest::shouldHaveDefaultValuesOnCreation()
     KPIMTextEdit::TextGoToLineWidget edit;
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
-    QSpinBox *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
     QVERIFY(line);
     QCOMPARE(line->minimum(), 1);
-    QPushButton *gotolinebutton = edit.findChild<QPushButton *>(QStringLiteral("gotoline"));
+    auto *gotolinebutton = edit.findChild<QPushButton *>(QStringLiteral("gotoline"));
     QVERIFY(gotolinebutton);
-    QToolButton *closebutton = edit.findChild<QToolButton *>(QStringLiteral("closebutton"));
+    auto *closebutton = edit.findChild<QToolButton *>(QStringLiteral("closebutton"));
     QVERIFY(closebutton);
     QVERIFY(line->hasFocus());
 }
@@ -50,7 +37,7 @@ void TextGoToLineWidgetTest::shouldHaveDefaultValuesOnCreation()
 void TextGoToLineWidgetTest::shouldEmitGoToLineSignalWhenPressOnButton()
 {
     KPIMTextEdit::TextGoToLineWidget edit;
-    QPushButton *gotolinebutton = edit.findChild<QPushButton *>(QStringLiteral("gotoline"));
+    auto *gotolinebutton = edit.findChild<QPushButton *>(QStringLiteral("gotoline"));
     QSignalSpy spy(&edit, &KPIMTextEdit::TextGoToLineWidget::moveToLine);
     QTest::mouseClick(gotolinebutton, Qt::LeftButton);
     QCOMPARE(spy.count(), 1);
@@ -59,8 +46,8 @@ void TextGoToLineWidgetTest::shouldEmitGoToLineSignalWhenPressOnButton()
 void TextGoToLineWidgetTest::shouldEmitGoToLineSignalCorrectValueWhenPressOnButton()
 {
     KPIMTextEdit::TextGoToLineWidget edit;
-    QPushButton *gotolinebutton = edit.findChild<QPushButton *>(QStringLiteral("gotoline"));
-    QSpinBox *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto *gotolinebutton = edit.findChild<QPushButton *>(QStringLiteral("gotoline"));
+    auto *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
     line->setValue(5);
     QCOMPARE(line->value(), 5);
     QSignalSpy spy(&edit, &KPIMTextEdit::TextGoToLineWidget::moveToLine);
@@ -75,7 +62,7 @@ void TextGoToLineWidgetTest::shouldHideWidgetWhenClickOnCloseButton()
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
     QVERIFY(edit.isVisible());
-    QToolButton *closebutton = edit.findChild<QToolButton *>(QStringLiteral("closebutton"));
+    auto *closebutton = edit.findChild<QToolButton *>(QStringLiteral("closebutton"));
     QTest::mouseClick(closebutton, Qt::LeftButton);
     QVERIFY(!edit.isVisible());
 }
@@ -94,7 +81,7 @@ void TextGoToLineWidgetTest::shouldEmitGoToLineSignalWhenSpinboxHasFocusAndWePre
     KPIMTextEdit::TextGoToLineWidget edit;
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
-    QSpinBox *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
     line->setFocus();
     QVERIFY(line->hasFocus());
     line->setValue(5);
@@ -109,7 +96,7 @@ void TextGoToLineWidgetTest::shouldHasFocusEachTimeThatItShown()
     KPIMTextEdit::TextGoToLineWidget edit;
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
-    QSpinBox *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
     QVERIFY(line);
     QVERIFY(line->hasFocus());
     edit.hide();
@@ -124,7 +111,7 @@ void TextGoToLineWidgetTest::shouldSetFocusWhenWeRecallGotToLine()
     KPIMTextEdit::TextGoToLineWidget edit;
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
-    QSpinBox *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
     QVERIFY(line->hasFocus());
     edit.setFocus();
     QVERIFY(!line->hasFocus());
@@ -137,7 +124,7 @@ void TextGoToLineWidgetTest::shouldChangeMaximumValue()
     KPIMTextEdit::TextGoToLineWidget edit;
     edit.show();
     QVERIFY(QTest::qWaitForWindowExposed(&edit));
-    QSpinBox *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
+    auto *line = edit.findChild<QSpinBox *>(QStringLiteral("line"));
 
     QCOMPARE(line->value(), 1);
     QCOMPARE(line->minimum(), 1);
